#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_STREAM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_STREAM_HPP_INCLUDED

#include <boost/simd/memory/include/functions/stream.hpp>

#endif
